package com.huimv.management.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.huimv.management.entity.YearPigBaseEntity;
import com.huimv.management.entity.vo.DrinkingWaterVo;
import com.huimv.management.entity.vo.PigBaseVo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.common.utils.PageUtils;
import com.huimv.common.utils.Query;
import com.huimv.management.dao.YearPigBaseDao;
import com.huimv.management.service.YearPigBaseService;




@Service("yearPigBaseService")
public class YearPigBaseServiceImpl extends ServiceImpl<YearPigBaseDao, YearPigBaseEntity> implements YearPigBaseService {

    @Autowired
    private YearPigBaseDao pigBaseDao;

//    @Override
//    public PageUtils queryPage(Map<String, Object> params) {
//
//        LambdaQueryWrapper<YearPigBaseEntity> lambdaQuery = Wrappers.lambdaQuery();
//        String keywords = (String) params.get("keywords");
//        //没有参数
//        if (keywords == null || keywords.equals("")){
//            IPage<YearPigBaseEntity> page = this.page(
//                    new Query<YearPigBaseEntity>().getPage(params),
//                    new QueryWrapper<YearPigBaseEntity>()
//            );
//            return new PageUtils(page);
//        }
//
//        lambdaQuery.like(YearPigBaseEntity::getBreed,keywords);
//        IPage<YearPigBaseEntity> page = page(this.page(
//                new Query<YearPigBaseEntity>().getPage(params)
//        ), lambdaQuery);
//
//
//        return new PageUtils(page);
//    }


    @Override
    public PageUtils queryPage(Map<String, Object> params) {

        //构建条件查询wrapper
        QueryWrapper<DrinkingWaterVo> queryWrapper = new QueryWrapper<>();

        //耳标
        String eartag = (String) params.get("eartag");
        if (StringUtils.isNotEmpty(eartag)) {
            queryWrapper.like("base.eartag",eartag);
        }

        //性别
        String sex = (String) params.get("sex");
        if (StringUtils.isNotEmpty(sex)) {
            queryWrapper.eq("base.sex",sex);
        }

        //品种
        String breed = (String) params.get("breed");
        if (StringUtils.isNotEmpty(breed)) {
            queryWrapper.eq("base.breed",breed);
        }

        //健康状态
        String healthStatus = (String) params.get("healthStatus");
        if (StringUtils.isNotEmpty(healthStatus)) {
            queryWrapper.eq("base.health_status",Integer.parseInt(healthStatus));
        }

        //养殖状态
        String outFenceStatus = (String) params.get("outFenceStatus");
        if (StringUtils.isNotEmpty(outFenceStatus)) {
            queryWrapper.eq("base.out_fence_status",Integer.parseInt(outFenceStatus));
        }

        //栏期
        String periodId = (String) params.get("periodId");
        if (StringUtils.isNotEmpty(periodId)) {
            queryWrapper.eq("base.period_id",Integer.parseInt(periodId));
        }

        //栋舍
        String pigstyId = (String) params.get("pigstyId");
        if (StringUtils.isNotEmpty(pigstyId)) {
            queryWrapper.eq("base.pigsty_id",Integer.parseInt(pigstyId));
        }
        //单元
        String unitId = (String) params.get("unitId");
        if (StringUtils.isNotEmpty(unitId)) {
            queryWrapper.eq("base.unit_id",Integer.parseInt(unitId));
        }

        //牧场
        String farmId = (String) params.get("formFarmId");
        if (StringUtils.isNotEmpty(farmId)) {
            queryWrapper.eq("base.farm_id",Integer.parseInt(farmId));
        }
        //排除逻辑删除
        queryWrapper.apply(" base.deleted = 0  AND pigsty.deleted = 0 AND period.deleted = 0");

        IPage<PigBaseVo> page = pigBaseDao.list(new Query<>().getPage(params),queryWrapper);



        return new PageUtils(page);
    }


    @Override
    public void batchLairage(String[] eartags,Integer periodId) {
        for (String eartag : eartags) {
            UpdateWrapper<YearPigBaseEntity> updateWrapper = new UpdateWrapper<YearPigBaseEntity>();
            updateWrapper.eq("eartag",eartag).set("period_id",periodId);
            update(updateWrapper);
        }
    }

    @Override
    public void such(Integer[] ids) {
        pigBaseDao.such(ids);
    }

    @Override
    public Integer findByoutFenceStatus(int i, Integer farmId) {
        LambdaQueryWrapper<YearPigBaseEntity> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(YearPigBaseEntity::getFarmId,farmId);
        wrapper.eq(YearPigBaseEntity::getOutFenceStatus,i);
        Integer integer = pigBaseDao.selectCount(wrapper);
        return integer;
    }


    @Override
    public   Map<String ,Object> queryPageByRelationship(Map<String, Object> params) {

        Map<String, Object> result = new HashMap<>();
        String eartag_no = (String) params.get("eartag");
        System.out.println(eartag_no);
        YearPigBaseEntity  self = baseMapper.selectOne(Wrappers.<YearPigBaseEntity>lambdaQuery().eq(YearPigBaseEntity::getEartag, eartag_no));
        System.out.println(self);
        result.put("self",   self  );


        System.out.println("父亲ID"+self.getFatherEartag());   System.out.println("母亲ID"+self.getMotherEartag());
        String math = self.getMotherEartag();

        YearPigBaseEntity father = self.getFatherEartag() == null ? null :  baseMapper.selectOne(Wrappers.<YearPigBaseEntity>lambdaQuery().eq(YearPigBaseEntity::getEartag, self.getFatherEartag()));
        YearPigBaseEntity mother = self.getMotherEartag() == null ? null :  baseMapper.selectOne(Wrappers.<YearPigBaseEntity>lambdaQuery().eq(YearPigBaseEntity::getEartag, math));



        //父亲父母
        result.put("father", father);
        result.put("mother", mother);
        YearPigBaseEntity fathermother = father == null ? null :  baseMapper.selectOne(Wrappers.<YearPigBaseEntity>lambdaQuery().eq(YearPigBaseEntity::getEartag, father.getFatherEartag()));
        YearPigBaseEntity fatherfather = father == null ? null :  baseMapper.selectOne(Wrappers.<YearPigBaseEntity>lambdaQuery().eq(YearPigBaseEntity::getEartag, father.getMotherEartag()));
        result.put("fathermother", fathermother);
        result.put("fatherfather", fatherfather);
        //母亲父母
        YearPigBaseEntity mothermother = mother == null ? null :  baseMapper.selectOne(Wrappers.<YearPigBaseEntity>lambdaQuery().eq(YearPigBaseEntity::getEartag, mother.getFatherEartag()));
        YearPigBaseEntity  motherfather = mother == null ? null :  baseMapper.selectOne(Wrappers.<YearPigBaseEntity>lambdaQuery().eq(YearPigBaseEntity::getEartag, mother.getMotherEartag()));
        result.put("mothermother", mothermother);
        result.put("motherfather", motherfather);


        return   result;
    }

}